==> univention-mail-postfix_14.0.7-1.tar.gz: univention-mail-postfix-14.0.7/hosteddomains.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-
#
# Univention Mail Stack
#  listener module: mail domain configuration
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2005-2024 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from __future__ import absolute_import, annotations

import re
from typing import Dict, List

import univention.config_registry
import univention.debug

import listener


description = 'update mail/hosteddomains'
filter = '(objectClass=univentionMailDomainname)'


def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]]) -> None:
    configRegistry = univention.config_registry.ConfigRegistry()
    configRegistry.load()

    old_hosteddomains = set(re.split('[ ]+', configRegistry.get('mail/hosteddomains', '')))
    hosteddomains = old_hosteddomains.copy()

    # remove old add new
    if old.get('cn'):
        hosteddomains.discard(old['cn'][0].decode('UTF-8'))
        univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: removed %r" % old['cn'][0])
    if new.get('cn'):
        hosteddomains.add(new['cn'][0].decode('UTF-8'))
        univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: added %r" % new['cn'][0])

    # if something changed then set UCR variable
    if old_hosteddomains != hosteddomains:
        try:
            listener.setuid(0)
            univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: %s" % u'mail/hosteddomains=%s' % ' '.join(hosteddomains))
            univention.config_registry.handler_set([u'mail/hosteddomains=%s' % ' '.join(hosteddomains)])
        finally:
            listener.unsetuid()

==> univention-mail-postfix_16.0.7.tar.gz: univention-mail-postfix-16.0.7/hosteddomains.py <==
#!/usr/bin/python3
#
# Univention Mail Stack
#  listener module: mail domain configuration
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2005-2024 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.

from __future__ import annotations

import re

import univention.config_registry
import univention.debug

import listener


description = 'update mail/hosteddomains'
filter = '(objectClass=univentionMailDomainname)'


def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]]) -> None:
    configRegistry = univention.config_registry.ConfigRegistry()
    configRegistry.load()

    old_hosteddomains = set(re.split('[ ]+', configRegistry.get('mail/hosteddomains', '')))
    hosteddomains = old_hosteddomains.copy()

    # remove old add new
    if old.get('cn'):
        hosteddomains.discard(old['cn'][0].decode('UTF-8'))
        univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: removed %r" % old['cn'][0])
    if new.get('cn'):
        hosteddomains.add(new['cn'][0].decode('UTF-8'))
        univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: added %r" % new['cn'][0])

    # if something changed then set UCR variable
    if old_hosteddomains != hosteddomains:
        try:
            listener.setuid(0)
            univention.debug.debug(univention.debug.LISTENER, univention.debug.INFO, "hosteddomains: %s" % 'mail/hosteddomains=%s' % ' '.join(hosteddomains))
            univention.config_registry.handler_set(['mail/hosteddomains=%s' % ' '.join(hosteddomains)])
        finally:
            listener.unsetuid()
